@@ -5,6 +5,7 @@ from datomizer.helpers import common_helper
 from datomizer.helpers.train import enhance_ml_helper, train_helper
 from datomizer.utils import general, step_types
 from datomizer.helpers.wrapper import schema_wrapper
+from datomizer.utils.enhance_ml import Metrics, Algorithms
 
 
 class DatoEnhancer(object):
@@ -28,7 +29,8 @@ class DatoEnhancer(object):
         dato_enhancer.wait()
         return dato_enhancer
 
-    def enhance(self, target_table="", target_column="", metric_list=[], algorithm_list=[], wait=True) -> None:
+    def enhance(self, target_table: str = "", target_column: str = "",
+                metric_list: [Metrics] = [], algorithm_list: [Algorithms] = [], wait=True) -> None:
         if self.train_id > 0:
             return
 
