@@ -40,15 +40,15 @@ class DatoGenerator(object):
             return
         self.datasource_id = datasource_helper.create_target_private_datasource(self.dato_trainer.dato_mapper.datomizer)
 
-    def generate(self, sample_output_ratio: float = 1, wait=True) -> None:
+    def generate(self, output_ratio: float = 1, wait=True) -> None:
         """Generate output data.
         Args:
-            sample_output_ratio: float represents the output ratio for generated data
+            output_ratio: float represents the output ratio for generated data
             wait: use wait=False for asynchronous programming; True by default (awaits for the results)."""
         self.create_datasource()
         if self.synth_id > 0:
             return
-        self.synth_id = generator_helper.generate(self.dato_trainer, self.datasource_id, sample_output_ratio)
+        self.synth_id = generator_helper.generate(self.dato_trainer, self.datasource_id, output_ratio)
         if wait:
             self.wait()
 
