@@ -1,6 +1,8 @@
 import requests
 from datomizer.utils import constants
 
+CLIENT = "direct-sdk"
+
 
 def get_domain_by_username(username: str, env: str = 'app') -> str:
     response = requests.get(constants.ONBOARDING_GET_USER_DOMAIN_DEFAULT % (env, username))
@@ -12,9 +14,9 @@ def get_realm_by_domain(domain: str) -> str:
     return response.text
 
 
-def get_token(username, password, realm, domain):
+def post_token(realm: str, domain: str, username: str, password: str):
     client_props = {
-        "client_id": "direct",
+        "client_id": CLIENT,
         "grant_type": "password",
         "username": username,
         "password": password
@@ -24,9 +26,9 @@ def get_token(username, password, realm, domain):
     return response.json()
 
 
-def refresh_token(realm, domain, token):
+def post_refresh_token(realm: str, domain: str, token: str):
     client_props = {
-        "client_id": "direct",
+        "client_id": CLIENT,
         "grant_type": "refresh_token",
         "refresh_token": token
     }
@@ -34,3 +36,12 @@ def refresh_token(realm, domain, token):
     response = requests.post(constants.KEYCLOAK_GET_TOKEN_URL % (domain, realm), client_props)
     return response.json()
 
+
+def post_log_out(realm: str, domain: str, token: str, refresh_token: str):
+    headers = {"Authorization": f"Bearer {token}"}
+    client_props = {
+        "client_id": CLIENT,
+        "refresh_token": refresh_token
+    }
+    response = requests.post(constants.KEYCLOAK_LOGOUT_URL % (domain, realm), client_props, headers=headers)
+    return response.text
