@@ -17,7 +17,7 @@ def create_synth_request(dato_trainer: DatoTrainer,
     }
 
 
-def generate(dato_trainer: DatoTrainer, datasource_id: int, sample_output_ratio: float = 1) -> int:
+def generate(dato_trainer: DatoTrainer, datasource_id: int, output_ratio: float = 1) -> int:
     dato_trainer.wait()
     response_json = dato_trainer.dato_mapper.datomizer.get_response_json(
         requests.put,
@@ -26,5 +26,5 @@ def generate(dato_trainer: DatoTrainer, datasource_id: int, sample_output_ratio:
                     dato_trainer.dato_mapper.project_id,
                     dato_trainer.dato_mapper.flow_id],
         headers={"Content-Type": "application/json"},
-        data=json.dumps(create_synth_request(dato_trainer, datasource_id, sample_output_ratio)))
+        data=json.dumps(create_synth_request(dato_trainer, datasource_id, output_ratio)))
     return response_json[general.ID]
