@@ -13,7 +13,9 @@ TENANT = "/tenant"
 TOKEN_RESOLVER = "/tokenResolver"
 REALM_NAME = "/realmName"
 
-KEYCLOAK_GET_TOKEN_URL = URL + KEYCLOAK + "/realms/%s/protocol/openid-connect/token"
+KEYCLOAK_BASE_URL = URL + KEYCLOAK + "/realms/%s/protocol/openid-connect/"
+KEYCLOAK_GET_TOKEN_URL = KEYCLOAK_BASE_URL + "token"
+KEYCLOAK_LOGOUT_URL = KEYCLOAK_BASE_URL + "logout"
 
 
 ONBOARDING_GET_USER_DOMAIN_DEFAULT = (URL % DEFAULT_DOMAIN) \
